@@ -7,7 +7,7 @@ from typing import Optional, Deque
 
 from feeluown.utils import aio
 from feeluown.utils.router import Router, NotFound
-from feeluown.models.uri import resolve, reverse, ResolveFailed, parse_line
+from feeluown.library import resolve, reverse, ResolveFailed, parse_line
 
 logger = logging.getLogger(__name__)
 
@@ -193,6 +193,10 @@ class Browser:
         from feeluown.gui.pages.song_explore import render as render_song_explore
         from feeluown.gui.pages.provider_home import render as render_provider_home
         from feeluown.gui.pages.recently_played import render as render_recently_played
+        from feeluown.gui.pages.recommendation import render as render_rec
+        from feeluown.gui.pages.recommendation_daily_songs import \
+            render as render_rec_daily_songs
+        from feeluown.gui.pages.my_fav import render as render_my_fav
 
         model_prefix = f'{MODEL_PAGE_PREFIX}<provider>'
 
@@ -209,6 +213,9 @@ class Browser:
             ('/providers/<identifier>', render_provider_home),
             ('/recently_played', render_recently_played),
             ('/search', render_search),
+            ('/rec', render_rec),
+            ('/rec/daily_songs', render_rec_daily_songs),
+            ('/my_fav', render_my_fav),
         ]
         for url, renderer in urlpatterns:
             self.route(url)(renderer)
