@@ -25,14 +25,11 @@ import logging
 from contextlib import contextmanager
 from typing import TypeVar, List, Optional, Generic, Union, cast, TYPE_CHECKING
 
-try:
-    # helper module should work in no-window mode
-    from PyQt5.QtCore import QModelIndex, QSize, Qt, pyqtSignal, QSortFilterProxyModel, \
-        QAbstractListModel
-    from PyQt5.QtGui import QPalette, QFontMetrics, QColor, QPainter
-    from PyQt5.QtWidgets import QApplication, QScrollArea, QWidget
-except ImportError:
-    pass
+from PyQt5.QtCore import QModelIndex, QSize, Qt, pyqtSignal, QSortFilterProxyModel, \
+    QAbstractListModel, QPoint
+from PyQt5.QtGui import QPalette, QFontMetrics, QColor, QPainter, QMouseEvent, \
+    QKeySequence
+from PyQt5.QtWidgets import QApplication, QScrollArea, QWidget, QShortcut
 
 from feeluown.utils.aio import run_afn, run_fn
 from feeluown.utils.reader import AsyncReader, Reader
@@ -40,6 +37,7 @@ from feeluown.utils.typing_ import Protocol
 from feeluown.excs import ProviderIOError, ResourceNotFound
 from feeluown.library import ModelNotFound, ModelType, BaseModel
 from feeluown.library import reverse
+from feeluown.gui.consts import FontFamilies
 
 
 if TYPE_CHECKING:
@@ -574,6 +572,53 @@ def secondary_text_color(palette: QPalette):
     return non_text_color
 
 
+class ClickableMixin:
+    clicked = pyqtSignal()
+
+    def __init__(self, **kwargs):
+        super().__init__(**kwargs)  # Cooperative multi-inheritance.
+
+        self._down = False
+
+    def mousePressEvent(self, e: QMouseEvent):
+        if e.button() != Qt.LeftButton:
+            # Call super.mousePressEvent because the concrete class may do sth inside it.
+            super().mousePressEvent(e)
+            return
+        if self._hit_button(e.pos()):
+            self._down = True
+            e.accept()
+        else:
+            super().mousePressEvent(e)
+
+    def mouseReleaseEvent(self, e: QMouseEvent):
+        if e.button() != Qt.LeftButton or not self._down:
+            super().mouseReleaseEvent(e)
+            return
+        self._down = False
+        if self._hit_button(e.pos()):
+            self.clicked.emit()
+            e.accept()
+        else:
+            super().mouseReleaseEvent(e)
+
+    def _hit_button(self, pos: QPoint):
+        return self.rect().contains(pos)
+
+    def set_down(self, down: bool):
+        self._down = down
+
+
+def set_default_font_families(widget):
+    font = widget.font()
+    font.setFamilies(FontFamilies)
+    widget.setFont(font)
+
+
+def esc_hide_widget(widget):
+    QShortcut(QKeySequence.Cancel, widget).activated.connect(widget.hide)
+
+
 # https://ethanschoonover.com/solarized/
 SOLARIZED_COLORS = {
     'yellow':    '#b58900',
