@@ -7,7 +7,7 @@ from PyQt5.QtWidgets import QLabel, QWidget, \
     QVBoxLayout, QSizeGrip, QHBoxLayout, QColorDialog, \
     QMenu, QAction, QFontDialog, QShortcut, QSpacerItem
 
-from feeluown.gui.helpers import resize_font, elided_text
+from feeluown.gui.helpers import esc_hide_widget, resize_font, elided_text
 from feeluown.player import LyricLine
 
 
@@ -72,7 +72,7 @@ class LyricWindow(QWidget):
 
         self._old_pos = None
 
-        QShortcut(QKeySequence.Cancel, self).activated.connect(self.hide)
+        esc_hide_widget(self)
 
     def mousePressEvent(self, e):
         self._old_pos = e.globalPos()
@@ -234,6 +234,7 @@ class InnerLyricWindow(QWidget):
         self.line_label = LineLabel(self)
 
         self._app.live_lyric.line_changed.connect(self.set_line)
+        self._app.live_lyric.lyrics_changed.connect(self.on_lyrics_changed)
         QShortcut(QKeySequence.ZoomIn, self).activated.connect(self.zoomin)
         QShortcut(QKeySequence.ZoomOut, self).activated.connect(self.zoomout)
         QShortcut(QKeySequence('Ctrl+='), self).activated.connect(self.zoomin)
@@ -264,6 +265,10 @@ class InnerLyricWindow(QWidget):
             self.parent().updateGeometry()   # type: ignore
         self.line_label.set_line(line)
 
+    def on_lyrics_changed(self, lyric, *_):
+        if lyric is None:
+            self.set_line(LyricLine('未找到可用歌词', '', False))
+
     def zoomin(self):
         label = self.line_label
         font = label.font()
