@@ -6,7 +6,7 @@ from PyQt5.QtGui import QPainter, QBrush, QColor, QLinearGradient, QPalette
 from PyQt5.QtWidgets import QFrame, QVBoxLayout, QStackedLayout
 
 from feeluown.utils import aio
-from feeluown.models import ModelType
+from feeluown.library import ModelType
 from feeluown.utils.reader import wrap
 
 from feeluown.gui.theme import Light
@@ -197,7 +197,10 @@ class RightPanel(QFrame):
             self._draw_pixmap(painter, draw_width, draw_height, scrolled)
             self._draw_pixmap_overlay(painter, draw_width, draw_height, scrolled)
             curve = QEasingCurve(QEasingCurve.OutCubic)
-            alpha_ratio = min(scrolled / max_scroll_height, 1)
+            if max_scroll_height == 0:
+                alpha_ratio = 1.0
+            else:
+                alpha_ratio = min(scrolled / max_scroll_height, 1.0)
             alpha = int(250 * curve.valueForProgress(alpha_ratio))
             painter.save()
             color = self.palette().color(QPalette.Window)
