@@ -17,10 +17,12 @@ from PyQt5.QtWidgets import (
 
 from feeluown.utils import aio
 from feeluown.utils.dispatch import Signal
-from feeluown.library import ModelState
+from feeluown.library import ModelState, ModelFlags, MediaFlags
 
 from feeluown.gui.mimedata import ModelMimeData
-from feeluown.gui.helpers import ItemViewNoScrollMixin, ReaderFetchMoreMixin
+from feeluown.gui.helpers import (
+    ItemViewNoScrollMixin, ReaderFetchMoreMixin, painter_save
+)
 
 
 logger = logging.getLogger(__name__)
@@ -468,6 +470,9 @@ class SongsTableDelegate(QStyledItemDelegate):
         painter.setRenderHint(QPainter.Antialiasing)
         hovered = index.row() == self.row_hovered
 
+        if index.column() == Column.song:
+            self.paint_vip_tag(painter, option, index)
+
         # Draw play button on Column.index when the row is hovered.
         if hovered and index.column() == Column.index:
             painter.save()
@@ -509,6 +514,30 @@ class SongsTableDelegate(QStyledItemDelegate):
             painter.drawRect(option.rect)
             painter.restore()
 
+    def paint_vip_tag(self, painter, option, index):
+        song = index.data(Qt.UserRole)
+        if ModelFlags.normal in song.meta.flags and MediaFlags.vip in song.media_flags:
+            with painter_save(painter):
+                fm = option.fontMetrics
+                title = index.data(Qt.DisplayRole)
+                title_rect = fm.boundingRect(title)
+                if title_rect.width() < option.rect.width():
+                    # Tested on (KDE and macOS):
+                    #   when font size is 7px, text width~>16 & height~>10
+                    font = option.font
+                    font.setPixelSize(7)
+                    painter.setFont(font)
+                    text_width, text_height = 16, 10
+                    y = option.rect.y() + (option.rect.height() - text_height) // 2
+                    # NOTE(cosven): On macOS, the acture width of text is large than
+                    # title_rect.width(), which is also true on KDE. This is decided
+                    # by QStyle. +10px works well on macOS, and it also works well
+                    # on KDE (actually, from local test, 7px is enough for KDE).
+                    x = option.rect.x() + title_rect.width() + 10
+                    text_rect = QRect(x, y, text_width, text_height)
+                    painter.drawRoundedRect(text_rect, 3, 3)
+                    painter.drawText(text_rect, Qt.AlignCenter, 'VIP')
+
     def sizeHint(self, option, index):
         """set proper width for each column
 
