@@ -12,7 +12,7 @@ from feeluown.utils.dispatch import Signal
 from feeluown.utils.utils import DedupList
 from feeluown.player import Metadata, MetadataFields
 from feeluown.library import (
-    MediaNotFound, SongModel, ModelType, ResourceNotFound,
+    MediaNotFound, SongModel, ModelType, ResourceNotFound, VideoModel,
 )
 from feeluown.media import Media
 from feeluown.library import reverse
@@ -94,6 +94,7 @@ class Playlist:
 
         #: store value for ``current_song`` property
         self._current_song = None
+        self._current_song_mv = None
 
         #: songs whose url is invalid
         self._bad_songs = DedupList()
@@ -119,6 +120,7 @@ class Playlist:
 
         emit(song, media)
         """
+        self.song_mv_changed = Signal()  # emit(song, mv)
 
         #: When watch mode is on, playlist try to play the mv/video of the song
         self.watch_mode = False
@@ -134,6 +136,7 @@ class Playlist:
         self.play_model_handling = Signal()
 
         self._app.player.media_finished.connect(self._on_media_finished)
+        self.song_changed.connect(self._on_song_changed)
 
     @property
     def mode(self):
@@ -420,6 +423,22 @@ class Playlist:
         else:
             self.next()
 
+    def _on_song_changed(self, song):
+        self._app.task_mgr.run_afn_preemptive(self._fetch_current_song_mv, song)
+
+    async def _fetch_current_song_mv(self, song):
+        if song is None:
+            self._current_song_mv = None
+        else:
+            try:
+                mv = await run_fn(self._app.library.song_get_mv, song)
+            except ProviderIOError:
+                logger.exception('get song mv info failed')
+                self._current_song_mv = None
+            else:
+                self._current_song_mv = mv
+        self.song_mv_changed.emit(song, self._current_song_mv)
+
     def previous(self) -> Optional[asyncio.Task]:
         """return to the previous song in playlist"""
         return self.set_current_song(self.previous_song)
@@ -436,6 +455,10 @@ class Playlist:
     def current_song(self, song: Optional[SongModel]):
         self.set_current_song(song)
 
+    @property
+    def current_song_mv(self) -> Optional[VideoModel]:
+        return self._current_song_mv
+
     def set_current_song(self, song) -> Optional[asyncio.Task]:
         """设置当前歌曲，将歌曲加入到播放列表，并发出 song_changed 信号
 
@@ -466,16 +489,12 @@ class Playlist:
         """
         target_song = song  # The song to be set.
         media = None        # The corresponding media to be set.
-
         try:
             media = await self._prepare_media(song)
         except MediaNotFound as e:
             if e.reason is MediaNotFound.Reason.check_children:
                 await self.a_set_current_song_children(song)
                 return
-
-            logger.info(f'no media found for {song} due to {e}, mark it as bad')
-            self.mark_as_bad(song)
         except ProviderIOError as e:
             # FIXME: This may cause infinite loop when the prepare media always fails
             logger.error(f'prepare media failed: {e}, try next song')
@@ -483,20 +502,29 @@ class Playlist:
             return
         except Exception as e:  # noqa
             # When the exception is unknown, we mark the song as bad.
-            self._app.show_msg(f'prepare media failed due to unknown error: {e}')
-            logger.exception('prepare media failed due to unknown error, '
-                             'so we mark the song as a bad one')
-            self.mark_as_bad(song)
+            self._app.show_msg(f'获取歌曲链接失败: {e}')
+            logger.exception('prepare media failed due to unknown error')
         else:
             assert media, "media must not be empty"
 
         # The song has no media, try to find and use standby unless it is in fm mode.
         if media is None:
-            # if mode is fm mode, do not find standby song, just skip the song.
-            if self.mode is PlaylistMode.fm:
-                run_afn(self.a_next)
-                return
-            target_song, media = await self.find_and_use_standby(song)
+            if self._app.config.ENABLE_MV_AS_STANDBY:
+                self._app.show_msg('尝试获取音乐视频的播放资源...')
+                media = await self._prepare_mv_media(song)
+
+            if media:
+                self._app.show_msg('使用音乐视频作为其播放资源 ✅')
+            else:
+                # if mode is fm mode, do not find standby song, just skip the song.
+                if self.mode is PlaylistMode.fm:
+                    self.mark_as_bad(song)
+                    run_afn(self.a_next)
+                    return
+
+                logger.info(f"no media found for {song}, mark it as bad")
+                self.mark_as_bad(song)
+                target_song, media = await self.find_and_use_standby(song)
 
         metadata = await self._prepare_metadata_for_song(target_song)
         self.pure_set_current_song(target_song, media, metadata)
@@ -515,17 +543,16 @@ class Playlist:
         return
 
     async def find_and_use_standby(self, song):
-        self._app.show_msg(f'{song} is invalid, try to find standby')
-        logger.info(f'try to find standby for {song}')
+        self._app.show_msg(f'{song} 无可用的播放资源, 尝试寻找备用歌曲...')
+        logger.info(f'try to find standby from other providers for {song}')
         standby_candidates = await self._app.library.a_list_song_standby_v2(
             song,
             self.audio_select_policy
         )
         if standby_candidates:
             standby, media = standby_candidates[0]
-            msg = f'song standby was found in {standby.source} ✅'
-            logger.info(msg)
-            self._app.show_msg(msg)
+            logger.info(f'song standby was found in {standby.source} ✅')
+            self._app.show_msg(f'在 {standby.source} 平台找到 {song} 的备用歌曲 ✅')
             # Insert the standby song after the song
             if song in self._songs and standby not in self._songs:
                 index = self._songs.index(song)
@@ -533,9 +560,8 @@ class Playlist:
                 self.songs_added.emit(index + 1, 1)
             return standby, media
 
-        msg = 'song standby not found'
-        logger.info(msg)
-        self._app.show_msg(msg)
+        logger.info(f'{song} song standby not found')
+        self._app.show_msg(f'未找到 {song} 的备用歌曲')
         return song, None
 
     def pure_set_current_song(self, song, media, metadata=None):
@@ -628,31 +654,35 @@ class Playlist:
         task_spec = self._app.task_mgr.get_or_create('prepare-media')
         task_spec.disable_default_cb()
         if self.watch_mode is True:
-            try:
-                mv_media = await task_spec.bind_blocking_io(
-                    self._app.library.song_prepare_mv_media,
-                    song,
-                    self._app.config.VIDEO_SELECT_POLICY)
-            except MediaNotFound:
-                mv_media = None
-                self._app.show_msg('No mv found')
-            except Exception as e:  # noqa
-                mv_media = None
-                self._app.show_msg(f'Prepare mv media failed: {e}')
+            mv_media = await task_spec.bind_coro(self._prepare_mv_media(song))
             if mv_media:
                 return mv_media
+            self._app.show_msg('未找到可用的歌曲视频资源')
         return await task_spec.bind_blocking_io(
             self._app.library.song_prepare_media, song, self.audio_select_policy)
 
+    async def _prepare_mv_media(self, song) -> Optional[Media]:
+        try:
+            mv_media = await run_fn(
+                self._app.library.song_prepare_mv_media,
+                song,
+                self._app.config.VIDEO_SELECT_POLICY)
+        except MediaNotFound:
+            mv_media = None
+        except Exception as e:  # noqa
+            mv_media = None
+            logger.exception(f'fail to get {song} mv: {e}')
+        return mv_media
+
     def set_current_model(self, model):
         """
         .. versionadded: 3.7.13
         """
-        if ModelType(model.meta.model_type) is ModelType.song:
-            return self.set_current_song(model)
         if model is None:
             self._app.player.stop()
             return
+        if ModelType(model.meta.model_type) is ModelType.song:
+            return self.set_current_song(model)
         return self._t_scm.bind_coro(self.a_set_current_model(model))
 
     async def a_set_current_model(self, model):
